#!/bin/bash

# Initialize

if [[ $EUID -ne 0 ]]; then
	echo "This script must be run as root. Use sudo " 
	exit 
fi

if  ! [ -f wiringPiI2C.RWBlockPatch ] &&  ! [ -f wiringPiI2C.headerPatch ] ; then
	echo "Files wiringPiI2C.RWBlockPatch and wiringPiI2C.headerPatch must be present in same directory as this script"
	exit
fi

echo -n "Looking for wiringPi source distribution... "
wiringPiDir=`find / -type d -path "*wiringPi/wiringPi" 2>/dev/null | tail -n 1`
if [[ ! "$wiringPiDir" =~ "wiringPi/wiringPi" ]]; then 
    echo
	echo "wiringPi not found."
	echo "Install wiringPi first."
	exit
fi
echo "found."

# Install Patch
echo -n "Patching wiringPi... "
	
if [[ $1 == "reinstall" ]]
then
	echo "Reset"
	cat ./wiringPiI2C.c > $wiringPiDir/wiringPiI2C.c
	cat ./wiringPiI2C.h > $wiringPiDir/wiringPiI2C.h
fi

if ! grep -q "wiringPiI2CWriteBlock" $wiringPiDir/wiringPiI2C.c 
then
	cat ./wiringPiI2C.RWBlockPatch >> $wiringPiDir/wiringPiI2C.c
fi

if ! grep -q "extern int wiringPiI2CReadBlock" $wiringPiDir/wiringPiI2C.h 
then
	cat ./wiringPiI2C.headerPatch  >> $wiringPiDir/wiringPiI2C.h
fi
echo "done."

# Compile
echo "Compiling new wiringPi library and install it..."
cd $wiringPiDir
#make clean
rm  -f /usr/local/lib/libwiringPi.so.?.? libwiringPi.so.?.?
make install
 	
echo "Done."


